@@ -13,10 +13,15 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_codestar_notifications.literals import (
+    DetailType,
+    ListEventTypesFilterName,
+    ListNotificationRulesFilterName,
+    ListTargetsFilterName,
+    NotificationRuleStatus,
+    TargetStatus,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -56,11 +61,7 @@ NotificationRuleSummaryTypeDef = TypedDict(
 
 TargetSummaryTypeDef = TypedDict(
     "TargetSummaryTypeDef",
-    {
-        "TargetAddress": str,
-        "TargetType": str,
-        "TargetStatus": Literal["PENDING", "ACTIVE", "UNREACHABLE", "INACTIVE", "DEACTIVATED"],
-    },
+    {"TargetAddress": str, "TargetType": str, "TargetStatus": TargetStatus},
     total=False,
 )
 
@@ -82,9 +83,9 @@ _OptionalDescribeNotificationRuleResultTypeDef = TypedDict(
         "EventTypes": List["EventTypeSummaryTypeDef"],
         "Resource": str,
         "Targets": List["TargetSummaryTypeDef"],
-        "DetailType": Literal["BASIC", "FULL"],
+        "DetailType": DetailType,
         "CreatedBy": str,
-        "Status": Literal["ENABLED", "DISABLED"],
+        "Status": NotificationRuleStatus,
         "CreatedTimestamp": datetime,
         "LastModifiedTimestamp": datetime,
         "Tags": Dict[str, str],
@@ -100,7 +101,7 @@ class DescribeNotificationRuleResultTypeDef(
 
 
 ListEventTypesFilterTypeDef = TypedDict(
-    "ListEventTypesFilterTypeDef", {"Name": Literal["RESOURCE_TYPE", "SERVICE_NAME"], "Value": str}
+    "ListEventTypesFilterTypeDef", {"Name": ListEventTypesFilterName, "Value": str}
 )
 
 ListEventTypesResultTypeDef = TypedDict(
@@ -110,8 +111,7 @@ ListEventTypesResultTypeDef = TypedDict(
 )
 
 ListNotificationRulesFilterTypeDef = TypedDict(
-    "ListNotificationRulesFilterTypeDef",
-    {"Name": Literal["EVENT_TYPE_ID", "CREATED_BY", "RESOURCE", "TARGET_ADDRESS"], "Value": str},
+    "ListNotificationRulesFilterTypeDef", {"Name": ListNotificationRulesFilterName, "Value": str}
 )
 
 ListNotificationRulesResultTypeDef = TypedDict(
@@ -125,8 +125,7 @@ ListTagsForResourceResultTypeDef = TypedDict(
 )
 
 ListTargetsFilterTypeDef = TypedDict(
-    "ListTargetsFilterTypeDef",
-    {"Name": Literal["TARGET_TYPE", "TARGET_ADDRESS", "TARGET_STATUS"], "Value": str},
+    "ListTargetsFilterTypeDef", {"Name": ListTargetsFilterName, "Value": str}
 )
 
 ListTargetsResultTypeDef = TypedDict(
